package com.cardiff.client_project.controller.hospital;

import com.cardiff.client_project.pojo.dto.HospitalDTO;
import com.cardiff.client_project.service.HospitalService;
import com.cardiff.client_project.utils.Result;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@RestController
@RequestMapping("/api/hospitals")
@PreAuthorize("hasAnyRole('ADMIN', 'HOSPITAL', 'SUPER')")
public class HospitalController {

    @Autowired
    private HospitalService hospitalService;

    @GetMapping("/available")
    public Result getAvailableBeds(
            @RequestParam(required = false, defaultValue = "") String name) {
        return hospitalService.getAvailableBeds(name);
    }

    @PostMapping
    public Result addHospital(@RequestBody HospitalDTO hospitalDTO) {
        return hospitalService.insertHospitalInfo(hospitalDTO);
    }

    @PutMapping("/{id}")
    public Result updateHospital(@PathVariable Integer id, @RequestBody HospitalDTO hospitalDTO) {
        hospitalDTO.setId(id);
        return hospitalService.updateHospital(hospitalDTO);
    }

    @DeleteMapping
    public Result deleteHospitals(@RequestBody List<Integer> ids) {
        return hospitalService.deleteHospitalById(ids);
    }

    @GetMapping
    public Result getAllHospitals() {
        return hospitalService.getAllHospitals();
    }
}
