package com.cardiff.client_project.service.imp;


import com.cardiff.client_project.constant.Authority;
import com.cardiff.client_project.constant.ResponseCode;
import com.cardiff.client_project.mapper.SuperAdminMapper;
import com.cardiff.client_project.mapper.PatientMapper;
import com.cardiff.client_project.pojo.dto.SelectDTO;
import com.cardiff.client_project.pojo.dto.SignUserDTO;
import com.cardiff.client_project.pojo.entity.CommonAdmin;
import com.cardiff.client_project.pojo.entity.Hospital;
import com.cardiff.client_project.pojo.vo.AdminVO;

import com.cardiff.client_project.pojo.vo.HospitalVO;
import com.cardiff.client_project.pojo.vo.SelectVO;
import com.cardiff.client_project.service.SuperAdminService;
import com.cardiff.client_project.utils.Result;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.crypto.password.PasswordEncoder;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;

@Service
public class SuperAdminServiceImp implements SuperAdminService {

    @Autowired
    private SuperAdminMapper superAdminMapper;
    @Autowired
    private PatientMapper patientMapper;
    @Autowired
    PasswordEncoder passwordEncoder;

    /**
     * User registration
     * @param signDTO
     * @return
     */
    @Override
    public Result insertUserInform(SignUserDTO signDTO) {
        //TODO
        Result result = null;
        if(signDTO.getRole().equals("HOSPITAL")){
            Hospital hospital = new Hospital();
            BeanUtils.copyProperties(signDTO,hospital);
            hospital.setRoleId(Authority.HOSPITAL);
            hospital.setPassword(passwordEncoder.encode(hospital.getPassword()));
            result= superAdminMapper.insertHospitalInform(hospital);
        }

        if (signDTO.getRole().equals("ADMIN")) {
            CommonAdmin commonAdmin = new CommonAdmin();
            BeanUtils.copyProperties(signDTO,commonAdmin);
            commonAdmin.setRoleId(Authority.ADMIN);
            commonAdmin.setPassword(passwordEncoder.encode(commonAdmin.getPassword()));
            result=superAdminMapper.insertUserInform(commonAdmin);
        }
//        if(signDTO.getRole().equals("PATIENT")){
//            commonAdmin.setRoleId(Authority.PATIENT);
//        }
       // Result result = superAdminMapper.insertUserInform(commonAdmin);
        return result;
    }

    /**
     * delete information by id
     * @param ids
     * @return
     */
    @Override
    public Result deleteById(List<Integer> ids,String type) {
        superAdminMapper.deleteByIdAndType(ids,type);
        return Result.success(ResponseCode.SUCCESS);
    }


    /**
     * Query admin information
     * @return
     */
    @Override
    public Result selectAllAdmin() {
        List<AdminVO> selectVOS = superAdminMapper.selectAllAdmin();

        List<AdminVO> adminVOS=new ArrayList<>();
        selectVOS.forEach(selectVO -> {
            AdminVO adminVO = new AdminVO();
            BeanUtils.copyProperties(selectVO, adminVO);  // Copy properties from selectVO to adminVO

            // Set the corresponding status string according to status
            if (adminVO.getStatus() == 1) {
                adminVO.setStatus_str("ACTIVE");
            }
            if (adminVO.getStatus() == 0) {
                adminVO.setStatus_str("INACTIVE");
            }
            // Added to the adminVOS list
            adminVOS.add(adminVO);
        });
        return Result.success(adminVOS);

    }


    /**
     * Query hospital information
     * @return
     */
    @Override
    public Result selectAllHospital() {
        List<Hospital> hospitals = superAdminMapper.selectAllHospital();
       // System.out.println(hospitals);
        List<HospitalVO> hospitalVOS =new ArrayList<>();
        hospitals.forEach(select -> {
            HospitalVO hospitalVO = new HospitalVO();
            BeanUtils.copyProperties(select, hospitalVO);  // Copy properties from selectVO to adminVO

            // Set the corresponding status string according to status
            if (hospitalVO.getStatus() == 1) {
                hospitalVO.setStatus_str("ACTIVE");
            }
            if (hospitalVO.getStatus() == 0) {
                hospitalVO.setStatus_str("INACTIVE");
            }
            // Added to the hospitalVOS list
            hospitalVOS.add(hospitalVO);
        });
        System.out.println("hospitalVO"+hospitalVOS);
        return Result.success(hospitalVOS);
    }

    /**
     * Update data
     * @param selectDTO
     * @return
     */
    @Override
    public Result update(SelectDTO selectDTO) {

        if(selectDTO.getType().equals("commonAdmin")){
            CommonAdmin commonAdmin = new CommonAdmin();
            BeanUtils.copyProperties(selectDTO,commonAdmin);
            List<AdminVO> adminVOS = superAdminMapper.update(commonAdmin);
            adminVOS.forEach(adminVO -> {
                if (adminVO.getStatus() == 1) {
                    adminVO.setStatus_str("ACTIVE");
                }else {
                    adminVO.setStatus_str("INACTIVE");
                }
            });
            return Result.success(adminVOS);
        }
        if(selectDTO.getType().equals("hospital")){
            Hospital hospital = new Hospital();
            BeanUtils.copyProperties(selectDTO,hospital);
            System.out.println("hospital:::"+hospital);
            List<Hospital> update = superAdminMapper.update(hospital);
            List<HospitalVO> hospitalVOS = new ArrayList<>();
            update.forEach(item->{
                HospitalVO hospitalVO = new HospitalVO();
                BeanUtils.copyProperties(item,hospitalVO);
                if (hospitalVO.getStatus() == 1) {
                    hospitalVO.setStatus_str("ACTIVE");
                }else {
                    hospitalVO.setStatus_str("INACTIVE");
                }
                hospitalVOS.add(hospitalVO);
            });
            return Result.success(hospitalVOS);
        }

        return Result.error(ResponseCode.ERROR);
    }


    /**
     * fuzzy query
     * @param selectDTO
     * @return
     */
    @Override
    public Result selectByItem(SelectDTO selectDTO) {
        List<SelectVO> selectVos = superAdminMapper.selectByItem(selectDTO);
       // System.out.println(selectVos);
        selectVos.forEach(selectVO -> {
            if (selectVO.getStatus() == 1) {
                selectVO.setStatus_str("ACTIVE");
            }
            if (selectVO.getStatus() == 0) {
                selectVO.setStatus_str("INACTIVE");
            }
        });

        if(selectVos.size()>0){
            return Result.success(selectVos);
        }else {
            return Result.error(ResponseCode.ACCOUNT_NOT_EXISTS);
        }

    }

    @Override
    public Result selectPage(String type, Integer pageSize, int pageNumber) {
        if(type.equals("commonAdmin")){
            List<CommonAdmin> commonAdmins = superAdminMapper.selectPageCommonAdmin(pageSize, pageNumber);
            //get all and count items
            List<AdminVO> adminVOS = superAdminMapper.selectAllAdmin();
            if(commonAdmins.size()>0){
                System.out.println(adminVOS.size());
                Integer count=adminVOS.size()%pageSize==0?adminVOS.size()/pageSize:adminVOS.size()/pageSize+1;
                return Result.success(count.toString(),commonAdmins);
            }
        }
        if(type.equals("hospital")){

        }
        return Result.error(ResponseCode.ERROR);
    }


}

